*******************************************************************************
*** This do file reproduces the results for 
*** Foundations of the Vanguard: The Origins of Leftist Rebel Groups
*** Megan A. Stewart (University of Michigan)
*******************************************************************************
*** Last update: October 15, 2022
*** Note 1: This file requires estout packages)	
*** To install, type: "ssc install estout, replace"                       
*** Note 2: Software version STATA/SE 16 used to conduct analysis	     
*******************************************************************************

clear
capture log close
set more off
*set scheme s2color
log using origins_leftists.smcl, replace

* Set Working Directory

cd "/Users/megan/Downloads/EJIR Replication"

*******************************************************************************
*** Pepare data with covariates to be merged into datasets 
*******************************************************************************

* Herre (2021)
use "global_leader_ideologies.dta", clear
sort country_code_cow year
collapse (max) leader_left, by (country_code_cow year)
gen ccodergd=country_code_cow
gen ccode_incumbent=country_code_cow
gen yrst=year
save "global_leader_ideologies_RGDprep.dta", replace

* Singer, Bremer, Stuckey et al. (1972)
use "NMC_5_0.dta", clear
replace milex=. if milex==-9
gen yrst=year
gen ccodergd=ccode
gen ccode_incumbent=ccode
save "NMC_5_0_RGDprep.dta", replace

* Fearon and Laitin (2003)
use "repdata 2.dta"
gen ccodergd=ccode
gen ccodeloc=ccode
gen ccode_location=ccode
gen yrst=year
save "FLrepdata_RGDprep.dta", replace

*******************************************************************************
*** Prepare Data for Additional Anti-Colonial Cases 
*******************************************************************************

clear
insheet using "COW country codes.csv"
rename statenme countryname
rename ccode ccode_real
rename stateabb stateabb3iso
sort stateabb3iso ccode_real countryname 
        . quietly by stateabb3iso ccode_real countryname:  gen dup = cond(_N==1,0,_n)
replace countryname="Bosnia" if countryname=="Bosnia and Herzegovina"
replace countryname="Congo-Brazzaville" if countryname=="Congo"
replace countryname="Congo-Zaire" if countryname=="Democratic Republic of the Congo"
replace countryname="Morocco/Western Sahara" if countryname=="Morocco" & dup==2
replace countryname="USSR" if countryname=="Russia" 
replace countryname="Yemen AR" if countryname=="Yemen Arab Republic"
replace countryname="South Yemen" if countryname=="Yemen People's Republic"
replace countryname="Myanmar/Burma" if countryname=="Myanmar" 
set obs `=_N+1'
replace countryname="Russia" if countryname==""
replace ccode_real=365 if ccode_real==.
replace stateabb="RUS" if stateabb3iso==""

drop dup
sort stateabb3iso ccode_real countryname 
        . quietly by stateabb3iso ccode_real countryname:  gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dup

save "cowcodes for extra data.dta", replace

*******************************************************************************
*** Prepare Location-Specifc Data  
*******************************************************************************

use "repdata 2.dta"
gen ccodeloc=ccode
* Generating cross-sectional data with one observation per country for time-invatirant varibles
sort ccodeloc 
        . quietly by ccodeloc:  gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dup
save "FLrepdata for extra data.dta", replace

*******************************************************************************
*** Prepare Conflict Data  
*******************************************************************************

import excel using "PRIO Battle Deaths Dataset 3.1.xls", first clear
keep if sidea=="United Kingdom" | sidea=="Portugal" |sidea=="Belgium" | sidea=="France" | sidea=="Netherlands"
replace bdeadbes=. if bdeadbes==-999
sort id year
by id: egen yearmin=min(year)
by id: egen yearmax=max(year)
order sideb, first
* Creating  *
replace sideb="PIRA, RIRA" if id==119
replace sideb="MPLA, UNITA, FNLA" if id==66
replace sideb="FLN, MNA" if id==49
collapse (max) yearmin yearmax, by (id location sidea sideb)
* No metropole cases *
drop if strpos(location,"United Kingdom")
drop if strpos(location,"France")
drop if strpos(location,"Portugal")
drop if strpos(location,"Netherlands")
* Note: Rationale for coding decisions included in Appendix *
gen marxist=0
replace marxist=. if location=="Mauritania" | location=="Brunei" | location=="Tunisia" 
replace marxist=1 if location=="Cambodia" |  location=="Vietnam" | location=="Malaysia" | location=="Cameroon" | location=="Angola" | location=="Guinea-Bissau" | location=="Mozambique"  
rename sideb conflict
rename yearmin yrst
rename yearmax yrend
rename sidea colonialruler
rename location countryname
gen newobs=1
gen ccodergd=.
replace ccodergd=200 if colonialruler=="United Kingdom" 
replace ccodergd=210 if colonialruler=="Netherlands" 
replace ccodergd=220 if colonialruler=="France" 
replace ccodergd=235 if colonialruler=="Portugal"
gen colruler=ccodergd
gen indfrom=ccodergd

*******************************************************************************
*** Merge Datasets
*******************************************************************************

* Add Cow Country Codes
merge 1:1 countryname using "cowcodes for extra data.dta"

gen ccodeloc=ccode_real
drop if _merge==2
drop _merge

* Add location specific factors from F&L (2003) 
merge 1:1 ccodeloc using "FLrepdata for extra data.dta", keepusing(numlang region western eeurop lamerica ssafrica asia nafrme mtnest lmtnest)
drop if _merge==2
* No Brunei in F&L data
rename _merge mergeFL

* Add Regime specific factors from NMC 5_0
merge m:1 ccodergd yrst using "NMC_5_0_RGDprep.dta", keepusing(milex tpop)
drop if _merge==2
rename _merge mergeNMC

* Add Regime Ideology 
merge m:1 ccodergd yrst using "global_leader_ideologies_RGDprep.dta", keepusing(leader_left)
drop if _merge==2
rename _merge mergeCOMREG2

* Create variable for whether a country is actively colonized.
* As all rebel groups are seeking independence, all are actively colonized
gen activecol=1
* Indicator for being a non-independent country

save "additionalcases.dta", replace


* Add additional cases to Huang (2016) an identify colonial ruler 
use "RGD main.dta"
gen ccodergd=cowccode
destring ccodergd, replace
gen ccodeloc=ccodergd
gen state=ccodergd
save "RGD MAS Update.dta", replace

merge m:1 state using "coldata110.dta", keepusing(colrul indfrom inddate cowsys)
drop if _merge==2
rename _merge mergeCOL
gen activecol=0
replace activecol=1 if inddate>=194400
replace activecol=. if indfrom==.

merge m:1 ccodeloc yrst using "FLrepdata_RGDprep.dta", keepusing(emplmtnest numlang region western eeurop lamerica ssafrica asia nafrme mtnest lmtnest)
drop if _merge==2
rename _merge mergeFL
* Ukraine/UPA and Namibia Missing

merge m:1 ccodergd yrst using "NMC_5_0_RGDprep.dta", keepusing(milex tpop)
drop if _merge==2
rename _merge mergeNMC
* Namibia Missing

merge m:1 ccodergd yrst using "global_leader_ideologies_RGDprep.dta", keepusing(leader_left)
drop if _merge==2
rename _merge mergeCOMREG2

append using "additionalcases.dta"
save "RGD MAS Update FULL.dta", replace

*******************************************************************************
*** Prep Variables for Analysis 
*******************************************************************************

* Ginea-Bissau and Mali
gen direct=0
replace direct=1 if colruler==235 | colruler==220
gen direct_alt=0
replace direct_alt=1 if indfrom==235 | indfrom==220

* Generate Cold War Variable
gen cw=1 if yrst<1991 
replace cw=0 if yrst>=1991

* Label Variables for output
label var marxist "Leftist"
label var direct "Direct Rule"
label var direct_alt "Direct Rule"
label var lmtnest "Rugged Terrain"
label var numlang "Languages Spoken"
label var milex "Military Expenditures"
label var tpop  "Total Population"
label var leader_left "Leftist Incumbent"

* Generate Sample Variable for Cold War==1 Active Colonilized==1
gen sample=0
replace sample=1 if cw==1 & activecol==1

*******************************************************************************
*** Analysis, Figure, and Table Output
*******************************************************************************

* Table 1.
tab marxist direct_alt if sample==1, chi2
 
 ***Among Former Colonies, Low Bar
local short1 "lmtnest numlang"
local controls1 "lmtnest numlang milex tpop leader_left"

* Table 2. 
eststo bivar: reg marxist i.direct_alt if sample==1, cluster(cowccode)
eststo short: reg marxist i.direct_alt `short1' if sample==1, cluster(cowccode)
eststo short_reg: reg marxist i.direct_alt `short1' i.region if sample==1, cluster(cowccode)
eststo full: reg marxist  i.direct_alt `controls1' if sample==1, cluster(cowccode)
eststo full_reg: reg marxist i.direct_alt `controls1' i.region if sample==1, cluster(cowccode)

* Output Table 2.
esttab bivar short short_reg full full_reg using "marxistmaincol.tex", replace title(Direct Colonial Rule Predicts the Emergence of Leftist Rebels  \label{marxist2}) ///
 stats(k r2_a N, fmt(%~12s %9.3f %9.0g) labels("Region Fixed Effects & No & No & Yes & No & Yes" R-squared Observations)) label cells(b(star fmt(3)) se(par fmt(3))) ///
 starlevels(+ 0.15 * 0.10 ** 0.05 *** 0.01) width(0.9\hsize) drop(*.regions_fl, relax) ///
 mlabels("" "" "" "" "") 

* Among Former Colonies, High Bar
* Table A.3
eststo bivarh: reg marxist i.direct if sample==1, cluster(cowccode)
eststo shorth: reg marxist i.direct `short1' if sample==1, cluster(cowccode)
eststo short_regh: reg marxist i.direct `short1' i.region if sample==1, cluster(cowccode)
eststo fullh: reg marxist  i.direct `controls1' if sample==1, cluster(cowccode)
eststo full_regh: reg marxist i.direct `controls1' i.region if sample==1, cluster(cowccode)

* Output Table A.3
esttab bivarh shorth short_regh fullh full_regh using "marxistmaincol2.tex", replace title(Direct Colonial Rule Predicts the Emergence of Leftist Rebels (High Bar) \label{marxist3}) ///
 stats(k r2_a N, fmt(%~12s %9.3f %9.0g) labels("Region Fixed Effects & No & No & Yes & No & Yes" R-squared Observations)) label cells(b(star fmt(3)) se(par fmt(3))) ///
 starlevels(+ 0.15 * 0.10 ** 0.05 *** 0.01) width(0.9\hsize) drop(*.regions_fl, relax) ///
 mlabels("" "" "" "" "") 

* Figure 1
reg marxist  direct_alt `controls1' i.region if sample==1, cluster(cowccode)
eststo full_regplot: margins, at((mean)_all direct_alt=(0(1)1)) post				
			
* Output Figure 1
coefplot (full_regplot,  levels(90))  ,  at ytitle("Probability of Leftist Rebel Group", size(large)) ylabel(, angle(horizontal))  ///
 xlabel(0 "No Direct Rule" 1 "Direct Rule", noticks) xscale(range(-.25,1.25) titlegap(4))  scheme(s1mono) plotregion(color(white))
graph save "predprob.gph", replace
graph export "predprob.pdf", replace	

* Appendix Summary Statistics, Cross-Sectional Analysis 
* Table A.1 & A.2
local controls2 "lmtnest numlang milex tpop leader_left"
eststo sum: estpost summarize  marxist direct_alt `controls2' if sample==1
eststo sumdirect: estpost summarize  marxist  `controls2' if sample==1 & direct_alt==1
eststo sumindirect: estpost summarize marxist `controls2' if sample==1 & direct_alt==0
* Output Table A.1 & A.2
esttab sum using "sumstats.tex",  replace cells("count mean sd min max") noobs label
esttab sumdirect sumindirect using "summarstats2.tex",  replace cells("count mean sd min max") noobs label
 
